Function to generate imputations using non-parametric and semi-parametric local imputation methods.
localImputation(
i,
preds,
y,
delta,
bw = NULL,
kernel = c("gaussian", "uniform", "triangular")
)integer referring to the index of the missing value to be imputed.
numeric vector of predictions of missing values from SuperLearner.
numeric vector for variable to be imputed.
binary vector of length length(y) indicating missingness.
1 where y is observed and 0 where y is missing.
NULL or numeric value for bandwidth of kernel function (as standard deviations of the kernel).
one of gaussian, uniform, or triangular.
Specifies the kernel to be used in estimating the distribution around a missing value.
numeric vector of randomly drawn imputed values.